@@ -1,6 +1,6 @@
 package App::Greple::xlate;
 
-our $VERSION = "0.99";
+our $VERSION = "0.9901";
 
 =encoding utf-8
 
@@ -16,7 +16,7 @@ App::Greple::xlate - translation support module for greple
 
 =head1 VERSION
 
-Version 0.99
+Version 0.9901
 
 =head1 DESCRIPTION
 
@@ -428,6 +428,7 @@ Read Japanese article in L</SEE ALSO> section for detail.
     Docker options
         -D * run xlate on the container with the same parameters
         -C * execute following command on the container, or run shell
+        -S * start the live container
         -A * attach to the live container
         N.B. -D/-C/-A terminates option handling
 
@@ -436,8 +437,8 @@ Read Japanese article in L</SEE ALSO> section for detail.
         -V # specify mount directory
         -U   do not mount
         -R   mount read-only
-        -K   do not remove and keep live container
-        -Q   quit and remove live container
+        -L   do not remove and keep live container
+        -K   kill and remove live container
         -E # specify environment variable to be inherited
         -I # docker image or version (default: tecolicom/xlate:version)
 
